.. image:: https://readthedocs.org/projects/odin/badge/
    :target: http://odin0.readthedocs.org/en/latest/

O.D.I.N
=======
Orgainzed Digital Intelligent Network (O.D.I.N)

O.D.I.N is a framework for building "Organized Digital Intelligent Networks", it uses Tensorflow to create and manage computational graph.

Its end-to-end design aims for a versatile input-to-output framework, that minimized the burden of repetitive work in machine learning pipeline, and allows researchers to conduct experiments in a faster and more flexible way.
